# Bayne - Bayesian Neural Networks
Pytorch/Pyro-based Bayesian Neural Networks library

Features:
- Markov Chain Monte Carlo (MCMC)
  - Full connectected neural network with ReLU, Sigmoid, or Tanh activation
  - Configurable prior
  - Hamiltonian Monte Carlo or NUTS sampler
- Bounds propagation
  - CROWN - linear bounds
  - IBP - interval bounds
  - CROWN-IBP - linear bounds

Authors:
- Frederik Baymler Mathiesen, PhD student @ TU Delft, Netherlands